@@ -8,12 +8,12 @@ from typing import Tuple
 from mmengine.fileio import load
 from mmengine.utils import check_file_exist
 
-PKG2PROJECT = {
+MODULE2PACKAGE = {
     'mmcls': 'mmcls',
     'mmdet': 'mmdet',
     'mmdet3d': 'mmdet3d',
     'mmseg': 'mmsegmentation',
-    'mmaction2': 'mmaction2',
+    'mmaction': 'mmaction2',
     'mmtrack': 'mmtrack',
     'mmpose': 'mmpose',
     'mmedit': 'mmedit',
@@ -28,6 +28,12 @@ PKG2PROJECT = {
     'mmyolo': 'mmyolo',
 }
 
+# PKG2PROJECT is not a proper name to represent the mapping between module name
+# (module import from) and package name (used by pip install). Therefore,
+# PKG2PROJECT will be deprecated and this alias will only be kept until
+# MMEngine v1.0.0
+PKG2PROJECT = MODULE2PACKAGE
+
 
 def _get_cfg_metainfo(package_path: str, cfg_path: str) -> dict:
     """Get target meta information from all 'metafile.yml' defined in `mode-
@@ -114,9 +120,9 @@ def _get_package_and_cfg_path(cfg_path: str) -> Tuple[str, str]:
                          'config name, but found multiple `::` in '
                          f'{cfg_path}')
     package, cfg_path = package_cfg
-    assert package in PKG2PROJECT, 'mmengine does not support to load ' \
-                                   f'{package} config.'
-    package = PKG2PROJECT[package]
+    assert package in MODULE2PACKAGE, (
+        f'mmengine does not support to load {package} config.')
+    package = MODULE2PACKAGE[package]
     return package, cfg_path
 
 
