@@ -36,6 +36,10 @@ def is_npu_available() -> bool:
     """Returns True if Ascend PyTorch and npu devices exist."""
     try:
         import torch_npu  # noqa: F401
+
+        # Enable operator support for dynamic shape and
+        # binary operator support on the NPU.
+        torch.npu.set_compile_mode(jit_compile=False)
     except Exception:
         return False
     return hasattr(torch, 'npu') and torch.npu.is_available()
