@@ -2,8 +2,12 @@
 import copy
 import datetime
 from collections import OrderedDict
+from itertools import chain
 from typing import List, Optional, Tuple
 
+import numpy as np
+import torch
+
 from mmengine.device import get_max_cuda_memory, is_cuda_available
 from mmengine.registry import LOG_PROCESSORS
 
@@ -206,8 +210,11 @@ class LogProcessor:
             log_str += '  '.join(log_items)
         return tag, log_str
 
-    def get_log_after_epoch(self, runner, batch_idx: int,
-                            mode: str) -> Tuple[dict, str]:
+    def get_log_after_epoch(self,
+                            runner,
+                            batch_idx: int,
+                            mode: str,
+                            with_non_scalar: bool = False) -> Tuple[dict, str]:
         """Format log string after validation or testing epoch.
 
         Args:
@@ -215,6 +222,8 @@ class LogProcessor:
             batch_idx (int): The index of the current batch in the current
                 loop.
             mode (str): Current mode of runner.
+            with_non_scalar (bool): Whether to include non-scalar infos in the
+                returned tag. Defaults to False.
 
         Return:
             Tuple(dict, str): Formatted log dict/string which will be
@@ -230,6 +239,7 @@ class LogProcessor:
         custom_cfg_copy = self._parse_windows_size(runner, batch_idx)
         # tag is used to write log information to different backends.
         tag = self._collect_scalars(custom_cfg_copy, runner, mode)
+        non_scalar_tag = self._collect_non_scalars(runner, mode)
         tag.pop('time', None)
         tag.pop('data_time', None)
         # By epoch:
@@ -252,11 +262,17 @@ class LogProcessor:
         # `time` and `data_time` will not be recorded in after epoch log
         # message.
         log_items = []
-        for name, val in tag.items():
+        for name, val in chain(tag.items(), non_scalar_tag.items()):
             if isinstance(val, float):
                 val = f'{val:.{self.num_digits}f}'
+            if isinstance(val, (torch.Tensor, np.ndarray)):
+                # newline to display tensor and array.
+                val = f'\n{val}\n'
             log_items.append(f'{name}: {val}')
         log_str += '  '.join(log_items)
+
+        if with_non_scalar:
+            tag.update(non_scalar_tag)
         return tag, log_str
 
     def _collect_scalars(self, custom_cfg: List[dict], runner,
@@ -305,6 +321,28 @@ class LogProcessor:
                     **log_cfg)
         return tag
 
+    def _collect_non_scalars(self, runner, mode: str) -> dict:
+        """Collect log information to compose a dict according to mode.
+
+        Args:
+            runner (Runner): The runner of the training/testing/validation
+                process.
+            mode (str): Current mode of runner.
+
+        Returns:
+            dict: non-scalar infos of the specified mode.
+        """
+        # infos of train/val/test phase.
+        infos = runner.message_hub.runtime_info
+        # corresponding mode infos
+        mode_infos = OrderedDict()
+        # extract log info and remove prefix to `mode_infos` according to mode.
+        for prefix_key, value in infos.items():
+            if prefix_key.startswith(mode):
+                key = prefix_key.partition('/')[-1]
+                mode_infos[key] = value
+        return mode_infos
+
     def _check_custom_cfg(self) -> None:
         """Check the legality of ``self.custom_cfg``."""
 
